@@ -54,17 +54,13 @@ static void manuallyPopulateParentMap(ParentMap *map, Stmt *s)
 ClazyASTConsumer::ClazyASTConsumer(ClazyContext *context)
     : m_context(context)
 {
-#ifndef CLAZY_DISABLE_AST_MATCHERS
     m_matchFinder = new clang::ast_matchers::MatchFinder();
-#endif
 }
 
 void ClazyASTConsumer::addCheck(const std::pair<CheckBase *, RegisteredCheck> &check)
 {
     CheckBase *checkBase = check.first;
-#ifndef CLAZY_DISABLE_AST_MATCHERS
     checkBase->registerASTMatchers(*m_matchFinder);
-#endif
     // m_createdChecks.push_back(checkBase);
 
     const RegisteredCheck &rcheck = check.second;
@@ -80,9 +76,7 @@ void ClazyASTConsumer::addCheck(const std::pair<CheckBase *, RegisteredCheck> &c
 
 ClazyASTConsumer::~ClazyASTConsumer()
 {
-#ifndef CLAZY_DISABLE_AST_MATCHERS
     delete m_matchFinder;
-#endif
     delete m_context;
 }
 
@@ -173,10 +167,8 @@ void ClazyASTConsumer::HandleTranslationUnit(ASTContext &ctx)
     // Run our RecursiveAstVisitor based checks:
     TraverseDecl(ctx.getTranslationUnitDecl());
 
-#ifndef CLAZY_DISABLE_AST_MATCHERS
     // Run our AstMatcher base checks:
     m_matchFinder->matchAST(ctx);
-#endif
 }
 
 static bool parseArgument(const std::string &arg, std::vector<std::string> &args)
