@@ -55,8 +55,8 @@ void FixItExporter::BeginSourceFile(const LangOptions &LangOpts, const Preproces
     }
 
     const auto id = SourceMgr.getMainFileID();
-    const auto *const entry = SourceMgr.getFileEntryForID(id);
-    getTuDiag().MainSourceFile = static_cast<std::string>(entry->getName());
+    const auto entry = SourceMgr.getFileEntryRefForID(id);
+    getTuDiag().MainSourceFile = entry->getName().str();
 }
 
 bool FixItExporter::IncludeInDiagnosticCounts() const
