@@ -12,14 +12,10 @@
 
 #include <string>
 
-class ClazyContext;
-
 namespace clang
 {
-class CXXConstructExpr;
 class CallExpr;
 class Expr;
-class Stmt;
 }
 
 /**
