@@ -15,11 +15,6 @@
 #include <clang/Lex/Token.h>
 #include <llvm/ADT/StringRef.h>
 
-namespace clang
-{
-class MacroInfo;
-} // namespace clang
-
 using namespace clang;
 
 QEnums::QEnums(const std::string &name, ClazyContext *context)
@@ -31,7 +26,7 @@ QEnums::QEnums(const std::string &name, ClazyContext *context)
 
 void QEnums::VisitMacroExpands(const Token &MacroNameTok, const SourceRange &range, const clang::MacroInfo *)
 {
-    PreProcessorVisitor *preProcessorVisitor = m_context->preprocessorVisitor;
+    const PreProcessorVisitor *preProcessorVisitor = m_context->preprocessorVisitor;
     if (!preProcessorVisitor || preProcessorVisitor->qtVersion() < 50500) {
         return;
     }
