@@ -11,14 +11,10 @@
 
 #include <string>
 
-class ClazyContext;
-
 namespace clang
 {
-class CXXConstructExpr;
 class ImplicitCastExpr;
 class CXXOperatorCallExpr;
-class Stmt;
 }
 
 /**
