@@ -15,13 +15,9 @@
 #include <set>
 #include <string>
 
-class ClazyContext;
-
 namespace clang
 {
 class ClassTemplateSpecializationDecl;
-class CXXRecordDecl;
-class Decl;
 class QualType;
 }
 
