@@ -17,17 +17,11 @@
 #include <string>
 #include <vector>
 
-class ClazyContext;
-
 namespace clang
 {
-class CallExpr;
-class CXXMemberCallExpr;
-class Expr;
 class FixItHint;
 class FunctionDecl;
 class MacroInfo;
-class Stmt;
 class Token;
 }
 
