@@ -11,12 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Decl;
-} // namespace clang
-
 /**
  * See README-qhash-with-char-pointer-key.md for more info.
  */
