@@ -12,14 +12,6 @@
 
 #include <string>
 
-class ClazyContext;
-
-namespace clang
-{
-class Stmt;
-class FixItHint;
-}
-
 /**
  * Replaces wrong headers with correct ones.
  *
@@ -37,7 +29,12 @@ public:
                                  clazy::OptionalFileEntryRef File,
                                  clang::StringRef SearchPath,
                                  clang::StringRef RelativePath,
+#if LLVM_VERSION_MAJOR >= 19
+                                 const clang::Module *SuggestedModule,
+                                 bool ModuleImported,
+#else
                                  const clang::Module *Imported,
+#endif
                                  clang::SrcMgr::CharacteristicKind FileType) override;
 };
 
