@@ -14,19 +14,12 @@
 
 #include <string>
 
-class ClazyContext;
 namespace clang
 {
 class CXXNamedCastExpr;
 class CXXRecordDecl;
-class Stmt;
 } // namespace clang
 
-namespace
-{
-class CXXNAmedCastExpr;
-}
-
 /**
  * Finds redundant casts.
  * See README-unneeded-cast.md for more info.
